function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
/* WooCommerce Step Filter Question
 * Original author: Alex Troll
 * Further changes, comments: mail@troll-winner.com
 */

(function (root, factory) {
  'use strict';

  if (typeof define === 'function' && define.amd) {
    define(['jquery'], factory);
  } else if ((typeof exports === "undefined" ? "undefined" : _typeof(exports)) === 'object' && typeof module !== 'undefined' && typeof require === 'function') {
    module.exports = factory(require('jquery'));
  } else {
    factory(root.jQuery);
  }
})(this, function ($) {
  'use strict';

  var pluginName = 'wcsfQuestion';
  var defaults = {};
  var $document = $(document);
  var Plugin = function Plugin(element, options) {
    this.element = element;
    this.options = $.extend({}, defaults, options);
    return this.init();
  };

  /**
   * Init the instance
   * @returns {this} self instance
   */
  Plugin.prototype.init = function () {
    var _this2 = this;
    this.$element = $(this.element);
    this.$settings = this.$element.find('[data-component~="wcsf-setting"]');
    this.$manualValues = this.$element.find('[data-component~="wcsf-question-manual-values"]');
    this.$filterType = this.$element.find('#_filter_type');
    this.$filterTypes = this.$filterType.find('option');
    this.$viewType = this.$element.find('#_view_type');
    this.ajaxUrl = this.$element.data('ajax-url');
    this.toggleFields();
    if ($.fn.sortable) {
      // init sortable
      this.$manualValues.sortable({
        items: '[data-component~="wcsf-question-manual-value"]',
        distance: 50,
        update: function update() {
          return _this2.recalculateIds();
        },
        cancel: 'input,textarea,button,select,option,.wcsf-modal'
      });
    }

    // disable not active manual source inputs
    this.$element.find('[data-component~="wcsf-question-manual-value-filter"].is-closed').find('[data-component="wcsf-question-manual-value-filter-values"]').attr('disabled', true);
    this.$element.find('[data-component~="wcsf-question-manual-value-filter-values-item-source"]').trigger('change'); // eslint-disable-line

    return this.initEventListeners();
  };

  /**
   * Add required event listeners
   * @returns {this} self instance
   */
  Plugin.prototype.initEventListeners = function () {
    var _this3 = this;
    var _this = this;
    this.$element.on('change', '#_view_type, #_filter_type', function () {
      return _this3.toggleFields();
    });

    // add manual filter row
    this.$element.on('click', '[data-component~="wcsf-question-add-value"]', function (event) {
      var _this4 = this;
      event.preventDefault();
      this.setAttribute('disabled', 'disabled');
      return _this.addValue().then(function () {
        return _this4.removeAttribute('disabled');
      });
    });

    // remove manual filter row
    this.$element.on('click', '[data-component~="wcsf-question-manual-value-remove"]', function (event) {
      event.preventDefault();
      var $value = _this.$element.find('[data-component~="wcsf-question-manual-value"]');
      var $valueToRemove = $value.filter("[data-index=\"".concat(this.getAttribute('data-index'), "\"]"));
      if ($value.length !== 1) {
        $valueToRemove.remove();
        _this.recalculateIds();
      }
    });

    // toggle manual filter source sections
    this.$element.on('change', '[data-component~="wcsf-question-manual-value-filter-by"]', function () {
      var $section = $(this).closest('[data-component~="wcsf-modal"]').find('[data-component~="wcsf-question-manual-value-filter"]');
      $section.addClass('is-closed').find('[data-component="wcsf-question-manual-value-filter-values"]').attr('disabled', true);
      $section.filter("[data-id=\"".concat(this.getAttribute('data-id'), "\"]")).removeClass('is-closed').find('[data-component="wcsf-question-manual-value-filter-values"]').removeAttr('disabled');
    });

    // manual value item source change
    this.$element.on('change', '[data-component~="wcsf-question-manual-value-filter-values-item-source"]', function () {
      // eslint-disable-line
      var $source = $(this);
      var $row = $source.closest('[data-component="wcsf-data-table-item"]');
      var $search = $row.find('[data-component~="wcsf-question-manual-value-filter-values-item-terms"]');
      var value = $source.val();
      switch (value) {
        case 'product_cat':
          $search.data('action', 'woocommerce_json_search_category');
          break;
        case 'product_tag':
          $search.data('action', 'woocommerce_json_search_tags');
          break;
        default:
          $search.data('action', "woocommerce_json_search_".concat(value));
      }
    });
  };

  /**
   * Show/hide fields
   * @returns {this} self instance
   */
  Plugin.prototype.toggleFields = function () {
    var filterType = this.$filterType.val();
    var viewType = this.$viewType.val();
    var numericViews = ['number', 'number-from', 'number-to', 'number-between'];
    var checkboxViews = ['checkbox', 'image-checkbox', 'chips-checkbox', 'button-checkbox'];
    var multiChoiceViews = ['multi-choice-checkbox', 'multi-choice-range'];
    var imagedViews = ['image-radio', 'image-checkbox'];
    var singleValueViews = ['select', 'radio', 'image-radio', 'chips-radio', 'button-radio'];
    var terms = ['attribute', 'tag', 'category'];
    var typesVisibilityRules = {
      price: ['formula'].concat(numericViews),
      manual: [].concat(singleValueViews, checkboxViews),
      category: [].concat(checkboxViews, singleValueViews, multiChoiceViews),
      tag: [].concat(checkboxViews, singleValueViews, multiChoiceViews),
      meta: ['formula', 'select', 'radio', 'checkbox', 'chips-radio', 'chips-checkbox', 'button-radio', 'button-checkbox'].concat(multiChoiceViews, numericViews)
    };
    var settingsVisibilityRulesByView = {
      formula: ['formula'],
      formula_operator: ['formula'],
      formula_variables: ['formula'],
      formula_name_aliases: ['formula'],
      formula_value_aliases: ['formula'],
      output_formula_value: ['formula'],
      formula_value_text: ['formula'],
      from_value_text: ['number-from', 'number-between'],
      to_value_text: ['number-to', 'number-between'],
      numeric_unit: numericViews,
      numeric_step: numericViews,
      enable_slider: numericViews,
      show_slider_tooltips: numericViews,
      show_inputs: numericViews,
      label_as_placeholder: numericViews,
      attribute_value_source: ['formula'].concat(numericViews),
      add_any_product_value: singleValueViews,
      any_product_value_text: singleValueViews,
      any_product_value_checked: singleValueViews,
      any_product_value_position: singleValueViews,
      any_product_value_thumbnail: ['image-radio'],
      add_empty_value: ['select'],
      empty_value_text: ['select'],
      alignment: imagedViews,
      thumbnail_size: imagedViews,
      thumbnail_width: imagedViews,
      multi_choice_values: multiChoiceViews,
      multi_choice_undefined_value_text: multiChoiceViews,
      multi_choice_possible_value_text: multiChoiceViews,
      multi_choice_required_value_text: multiChoiceViews,
      multi_choice_excluded_value_text: multiChoiceViews,
      hide_empty_terms: [].concat(checkboxViews, singleValueViews),
      included_terms: [].concat(checkboxViews, singleValueViews),
      excluded_terms: [].concat(checkboxViews, singleValueViews),
      unmet_values_behavior: [].concat(checkboxViews, singleValueViews, numericViews),
      show_count: [].concat(checkboxViews, singleValueViews, multiChoiceViews),
      show_description: [].concat(checkboxViews, singleValueViews, multiChoiceViews),
      action_on_click: [].concat(checkboxViews, singleValueViews, multiChoiceViews),
      additional_get_param: [].concat(checkboxViews, singleValueViews, numericViews),
      additional_get_param_term_source: [].concat(checkboxViews, singleValueViews),
      min_values_selected: checkboxViews,
      min_values_selected_message: checkboxViews,
      max_values_selected: checkboxViews,
      max_values_selected_message: checkboxViews,
      relation: checkboxViews
    };
    var settingsVisibilityRulesByType = {
      attribute: ['attribute'],
      attribute_value_source: ['attribute'],
      add_any_product_value: [].concat(terms, ['meta']),
      any_product_value_text: [].concat(terms, ['meta']),
      any_product_value_checked: [].concat(terms, ['meta']),
      any_product_value_position: [].concat(terms, ['meta']),
      any_product_value_thumbnail: [].concat(terms, ['meta']),
      additional_get_param_term_source: terms,
      category_parent: ['category'],
      category_parent_by_question: ['category'],
      start_from_categories_level: ['category'],
      max_sub_categories_level: ['category'],
      hide_empty_terms: terms,
      included_terms: terms,
      excluded_terms: terms,
      show_count: terms,
      show_description: terms,
      manual: ['manual'],
      meta_key: ['meta']
    };

    // toggle types according to the selected view
    this.$filterTypes.each(function () {
      if (!typesVisibilityRules.hasOwnProperty(this.getAttribute('value'))) {
        return null;
      }
      var hide = $.inArray(viewType, typesVisibilityRules[this.getAttribute('value')]) === -1;
      if (hide) {
        this.setAttribute('disabled', 'disabled');
      } else {
        this.removeAttribute('disabled');
      }
      return this;
    });

    // reset select if disabled option was selected
    if (!this.$filterType.val()) {
      this.$filterType.val(this.$filterType.find('option:not(disabled):eq(0)').attr('value'));
      filterType = this.$filterType.val();
    }

    // toggle settings according to the selected view
    this.$settings.each(function () {
      var $element = $(this);
      if (!settingsVisibilityRulesByView.hasOwnProperty(this.getAttribute('data-key'))) {
        return null;
      }
      var hide = $.inArray(viewType, settingsVisibilityRulesByView[this.getAttribute('data-key')]) === -1;
      $element[hide ? 'addClass' : 'removeClass']('is-hidden-by-view');
      return this;
    });

    // toggle settings according to the selected type
    this.$settings.each(function () {
      var $element = $(this);
      if (!settingsVisibilityRulesByType.hasOwnProperty(this.getAttribute('data-key'))) {
        return null;
      }
      var hide = $.inArray(filterType, settingsVisibilityRulesByType[this.getAttribute('data-key')]) === -1;
      $element[hide ? 'addClass' : 'removeClass']('is-hidden-by-type');
      return this;
    });
    return this;
  };

  /**
   * Makes the ajax-request and add manual value fields row
   * @returns {Promise} ajax request
   */
  Plugin.prototype.addValue = function () {
    var _this5 = this;
    var data = {
      action: 'wcsfAddQuestionValue',
      postId: this.$element.data('post-id'),
      index: this.$manualValues.find('[data-component~="wcsf-question-manual-value"]').length
    };
    return $.get(this.ajaxUrl, data, function (response) {
      _this5.$manualValues.append(response);
      var $element = _this5.$manualValues.find('[data-component~="wcsf-question-manual-value"]:last');
      $document.trigger('added.value.question.wcsf', [_this5, $element]);
    });
  };

  /**
   * Recalculate input names indexes
   * @returns {Object} jQuery elements
   */
  Plugin.prototype.recalculateIds = function () {
    return this.$element.find('[data-component~="wcsf-question-manual-value"]').each(function (index) {
      var $element = $(this);

      // change item index
      this.setAttribute('data-index', index);

      // change item children index
      $element.find('[data-index]').each(function () {
        return this.setAttribute('data-index', index);
      });
      return $element.find(':input').each(function () {
        var name = this.getAttribute('name');
        if (name) {
          var number = index.toString().split('').reverse().join(''); // eslint-disable-line

          // replace the first array key from the end
          this.setAttribute('name', name.split('').reverse().join('').replace(/]\d+\[/, "]".concat(number, "[")).split('').reverse().join(''));
        }
      });
    });
  };
  $.fn[pluginName] = function (options) {
    return this.each(function () {
      if (!$.data(this, pluginName)) {
        $.data(this, pluginName, new Plugin(this, options));
      }
    });
  };
  var init = function init() {
    return $('[data-component~="wcsf-question"]').each(function () {
      return $(this).wcsfQuestion();
    });
  };
  $document.ready(function () {
    return init();
  });
  $document.on('init.wcsfQuestion', function () {
    return init();
  });
});