<?php
namespace WCStepFilter;

/**
 * Admin Class
 *
 * @class Admin
 * @version 3.0.0
 */
class Admin
{
    // <editor-fold desc="Core">
    /** Class Constructor */
    public function __construct()
    {
        // scripts and styles
        add_action('admin_enqueue_scripts', [$this, 'enqueueAssets'], 9);

        // main actions
        add_action('admin_init', [$this, 'initAction']);
        add_action('admin_notices', [$this, 'noticesAction'], 10, 2);
        add_action('admin_menu', [$this, 'registerSettingsPageMenuItem']);
        add_filter('woocommerce_get_settings_pages', [$this, 'addSettingsTab']);
        add_action('plugins_loaded', [$this, 'pluginsLoadedAction']);

        // plugin links
        add_filter('plugin_action_links', [$this, 'actionLinksFilter'], 10, 2);
        add_filter('plugin_row_meta', [$this, 'metaLinksFilter'], 10, 2);
    }

    /** Styles and scripts enqueue in admin */
    public function enqueueAssets()
    {
        $path = WC_STEP_FILTER_DEBUG ? 'src' : 'assets';
        $suffix = WC_STEP_FILTER_DEBUG ? '' : '.min';
        $stylesFolder = WC_STEP_FILTER_DEBUG ? 'scss' : 'css';

        wp_enqueue_media();
        wp_enqueue_script('jquery');
        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_script(
            'woocommerce-step-filter-data-table',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/js/data-table$suffix.js",
            [
                'jquery',
                'jquery-ui-sortable'
            ],
            WC_STEP_FILTER_VERSION,
            true
        );

        wp_enqueue_script(
            'woocommerce-step-filter-ajax-select',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/js/ajax-select$suffix.js",
            ['jquery'],
            WC_STEP_FILTER_VERSION,
            true
        );

        wp_enqueue_script(
            'woocommerce-step-filter-thumbnail',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/js/thumbnail$suffix.js",
            ['jquery'],
            WC_STEP_FILTER_VERSION,
            true
        );

        wp_enqueue_script(
            'woocommerce-step-filter-multi-select',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/js/multi-select$suffix.js",
            ['jquery'],
            WC_STEP_FILTER_VERSION,
            true
        );

        wp_enqueue_script(
            'woocommerce-step-filter-sorting',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/js/sorting$suffix.js",
            ['jquery'],
            WC_STEP_FILTER_VERSION,
            true
        );

        wp_enqueue_script(
            'woocommerce-step-filter-hooks',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/js/hooks$suffix.js",
            ['jquery'],
            WC_STEP_FILTER_VERSION,
            true
        );

        wp_enqueue_style(
            'woocommerce-step-filter',
            WC_STEP_FILTER_PLUGIN_URL . "$path/admin/$stylesFolder/app$suffix.css",
            [],
            WC_STEP_FILTER_VERSION
        );
    }

    /** Admin notices hook */
    public function noticesAction()
    {
        require_once(__DIR__ . DIRECTORY_SEPARATOR . 'Legacy.php');

        $version = get_option('woocommerce_step_filter_version', null);

        global $pagenow;

        if (is_null($version)) {
            $version = WC_STEP_FILTER_VERSION;
            update_option('woocommerce_step_filter_version', WC_STEP_FILTER_VERSION);
        }

        if (version_compare($version, Legacy::$lastChangedVersion, '<')) {
            $updateURL = wp_nonce_url(
                add_query_arg('init_update_woocommerce_step_filter', 'true'),
                'wcsf_db_update_init',
                'wcsf_db_update_init_nonce'
            );

            $dismissURL = wp_nonce_url(
                add_query_arg('dismiss_update_woocommerce_step_filter', 'true'),
                'wcsf_db_update_dismiss',
                'wcsf_db_update_dismiss_nonce'
            );
            ?>
            <div class="notice notice-warning is-dismissible">
                <p><strong><?php L10N::e('WooCommerce Step Filter database update required'); ?></strong></p>
                <p><?php
                    // phpcs:disable
                    L10N::e('WooCommerce Step Filter has been updated! To keep things running smoothly, we have to update your database to the newest version.');
                    // phpcs:enable
                    ?></p>
                <p>
                    <a href="<?php echo esc_url($updateURL); ?>" class="wcsf-update-init button-primary"><?php
                        L10N::e('Update WooCommerce Step Filter Database');
                        ?></a>
                    <a href="<?php echo esc_url($dismissURL); ?>" class="wcsf-update-dismiss button"><?php
                        L10N::e('Dismiss');
                        ?></a>
                </p>
            </div>
            <?php
        }

        if (!API::getPurchaseToken() && $pagenow == 'post.php'
            && isset($_GET['post']) && get_post_type($_GET['post']) == Filter::$postType
        ) {
            ?>
            <div class="notice notice-warning is-dismissible">
                <p><a href="<?php
                    echo esc_url(admin_url('admin.php?page=wc-settings&tab=step_filter&section=license'));
                    ?>"><?php
                    L10N::e('Verify your license key to unlock extra possibilities and enable auto-updates');
                        ?></a></p>
            </div>
            <?php
        }
    }

    /** Admin init hook */
    public function initAction()
    {
        if (!empty($_GET['dismiss_update_woocommerce_step_filter'])) { // WPCS: input var ok.
            check_admin_referer('wcsf_db_update_dismiss', 'wcsf_db_update_dismiss_nonce');
            update_option('woocommerce_step_filter_version', WC_STEP_FILTER_VERSION);
        }

        if (!empty($_GET['init_update_woocommerce_step_filter'])) { // WPCS: input var ok.
            check_admin_referer('wcsf_db_update_init', 'wcsf_db_update_init_nonce');

            require_once(__DIR__ . DIRECTORY_SEPARATOR . 'Legacy.php');

            // init Legacy class
            new Legacy();

            update_option('woocommerce_step_filter_version', WC_STEP_FILTER_VERSION);

            add_action('admin_notices', function () {
                // phpcs:disable
                echo '<div class="notice notice-success is-dismissible"><p>'
                    . L10N::r('WooCommerce Step Filter database update complete. Thank you for updating to the latest version!')
                    . '</p></div>';
                // phpcs:enable
            });
        }
    }

    /**
     * Plugins list meta link filter
     *
     * @param array $links
     * @param string $plugin
     *
     * @return array
     */
    public function metaLinksFilter($links, $plugin)
    {
        if (false === strpos($plugin, 'woocommerce-step-filter.php')) {
            return $links;
        }

        $extraLinks = [
            'docs' => '<a href="https://step-filter.troll-winner.ru/docs/" target="_blank" rel="nofollow noopener">'
                . L10N::r('Docs') . '</a>'
        ];

        if (!API::getPurchaseToken()) {
            $extraLinks['license'] = '<a class="file-error" href="'
                . esc_url(admin_url('admin.php?page=wc-settings&tab=step_filter&section=license'))
                . '">' . L10N::r('Verify license') . '</a>';
        }

        $links = array_merge($links, $extraLinks);

        return $links;
    }

    /**
     * Plugins list action links filter
     *
     * @param array $links
     * @param string $plugin
     *
     * @return array
     */
    public function actionLinksFilter($links, $plugin)
    {
        if (false === strpos($plugin, 'woocommerce-step-filter.php')) {
            return $links;
        }

        $extraLinks = [
            'settings' => '<a href="admin.php?page=wc-settings&tab=step_filter">'
                . L10N::r('Settings') . '</a>'
        ];

        $links = array_merge($extraLinks, $links);

        return $links;
    }

    /** Handles then plugins are loaded */
    public function pluginsLoadedAction()
    {
        if (Core::$wcIsActive) {
            return;
        }

        add_action('admin_notices', function () {
            echo '<div class="notice notice-warning is-dismissible"><p>'
                . L10N::r('WooCommerce is required for WC Step Filter')
                . '</p></div>';
        });
    }
    // </editor-fold>

    // <editor-fold desc="Settings">
    /** Register settings page menu item action */
    public function registerSettingsPageMenuItem()
    {
        add_submenu_page(
            'edit.php?post_type=' . Filter::$postType,
            L10N::r('Plugin Settings'),
            L10N::r('Plugin Settings'),
            'manage_options',
            esc_url(admin_url('admin.php?page=wc-settings&tab=step_filter'))
        );
    }

    /**
     * Add filter page to the woocommerce options page
     *
     * @param array $includes
     *
     * @return array
     */
    public function addSettingsTab($includes)
    {
        if (!class_exists('\\WCStepFilter\\Settings_Page')) {
            require_once(__DIR__ . DIRECTORY_SEPARATOR . 'Settings_Page.php');
        }

        $includes[] = new Settings_Page(Core::getSettingsModel());

        return $includes;
    }

    /**
     * Generate html-field from passed args
     *
     * @param array $modelItem
     * @param array $args
     */
    public static function settingFieldView($modelItem, $args = [])
    {
        $defaultArgs = [
            'values' => [],
            'namePattern' => '%key%',
            'idPattern' => '%key%',
            'generateId' => true,
            'asTemplate' => false
        ];

        $args = array_replace($defaultArgs, $args);

        // create name from pattern
        $args['name'] = str_replace('%key%', $modelItem['key'], $args['namePattern']);

        // define value
        $args['value'] = isset($args['values'][$modelItem['key']])
            ? $args['values'][$modelItem['key']]
            : (isset($modelItem['default']) ? $modelItem['default'] : '');

        // define id attribute
        $args['id'] = $args['generateId'] ? str_replace('%key%', $modelItem['key'], $args['idPattern']) : false;

        $viewPath = __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR
            . 'setting-field-views' . DIRECTORY_SEPARATOR . $modelItem['type'] . '.php';

        echo isset($modelItem['before']) ? $modelItem['before'] : '';

        if (file_exists($viewPath)) {
            include($viewPath);
        }

        echo isset($modelItem['after']) ? $modelItem['after'] : '';

        if (isset($modelItem['description'])) {
            echo '<p class="description">' . wp_kses_post($modelItem['description']) . '</p>';
        }
    }
    // </editor-fold>
}
