<?php
namespace WCStepFilter;

/**
 * PDF Class
 *
 * @class PDF
 * @version 1.1.0
 */
class PDF
{
    /**
     * Current working filter results PDF total pages
     * @var int
     */
    public $currentTotalPages = null;
    
    /** Class Constructor */
    public function __construct()
    {
        add_action('woocommerce_after_register_post_type', [$this, 'wcProductRegisteredAction'], 1);
    }
    
    /** Handles then woocommerce product is registered */
    public function wcProductRegisteredAction()
    {
        if (isset($_GET['wcsf-results-pdf']) && $_GET['wcsf-results-pdf']) {
            $args = ['id' => (int) $_GET['wcsf-results-pdf']];

            if (isset($_GET['wcpw-id'], $_GET['wcpw-step-id'])) {
                $args['wizardArguments'] = [
                    'id' => $_GET['wcpw-id'],
                    'stepId' => $_GET['wcpw-step-id']
                ];
            }

            self::outputResults($args);
        }
    }
    
    /**
     * Generate and return URL and path for results PDF
     *
     * @param array $args
     *
     * @return null|object
     */
    public function getResultsInstance($args)
    {
        do_action('wcsf_before_get_results_pdf', $args);

        if (!class_exists('\Dompdf\Dompdf')) {
            require_once(__DIR__ . '/../vendor/dompdf/autoload.inc.php');
        }

        $defaults = [
            'id' => null,
            'formData' => []
        ];

        $args = array_replace($defaults, $args);

        do_action('wcsf_before_output', $args);

        $options = new \Dompdf\Options();
        do_action('wcsf_dompdf_options', $options, $args);

        $dompdf = new \Dompdf\Dompdf($options);
        do_action('wcsf_dompdf_instance', $dompdf, $args);

        $dompdf->loadHtml(Template::html('products/pdf', $args, ['echo' => false]));
        $dompdf->render();

        $args['pageTotal'] = $this->currentTotalPages = (int) $dompdf->getCanvas()->get_page_count();

        $dompdf = new \Dompdf\Dompdf();
        $dompdf->loadHtml(Template::html('products/pdf', $args, ['echo' => false]));
        $dompdf->render();

        do_action('wcsf_after_output', $args);

        return apply_filters('wcsf_results_pdf_instance', $dompdf, $args);
    }

    /**
     * Save results PDF to a file and return its URL and path
     *
     * @param array $args
     *
     * @return null|array
     */
    public function saveResults($args)
    {
        $defaults = ['name' => get_bloginfo('name')];
        $args = array_replace($defaults, $args);
        $dompdf = $this->getResultsInstance($args);

        if (!$dompdf) {
            return null;
        }

        $name = apply_filters('wcsf_results_pdf_file_name', $args['name'], $args);
        $path = WC_STEP_FILTER_UPLOADS_PATH . 'pdf' . DIRECTORY_SEPARATOR . "$name.pdf";
        $url = WC_STEP_FILTER_UPLOADS_URL . 'pdf' . DIRECTORY_SEPARATOR . "$name.pdf";

        // create uploads folder if not exists
        if (!file_exists(WC_STEP_FILTER_UPLOADS_PATH)) {
            mkdir(WC_STEP_FILTER_UPLOADS_PATH, 0777, true);
        }

        // create pdf folder if not exists
        if (!file_exists(WC_STEP_FILTER_UPLOADS_PATH . 'pdf')) {
            mkdir(WC_STEP_FILTER_UPLOADS_PATH . 'pdf', 0777, true);
        }

        file_put_contents($path, $dompdf->output());

        $output = [
            'url' => $url,
            'path' => $path,
            'pdf' => $dompdf
        ];

        return apply_filters('wcsf_results_pdf_file', $output, $args);
    }

    /**
     * Output results PDF
     *
     * @param array $args
     */
    public function outputResults($args)
    {
        $defaults = ['name' => get_bloginfo('name')];
        $args = array_replace($defaults, $args);
        $dompdf = $this->getResultsInstance($args);

        if (!$dompdf) {
            return;
        }

        $name = apply_filters('wcsf_results_pdf_file_name', $args['name'], $args);
        $dompdf->stream($name, ['Attachment' => false]);

        exit();
    }

    /**
     * Prepare HTML content for PDF using
     *
     * @param string $content
     * @param array $replacements - key => value to replace in content
     *
     * @return string
     */
    public static function prepareContent($content, $replacements = [])
    {
        if (!empty($replacements)) {
            $content = str_replace(array_keys($replacements), $replacements, $content);
        }

        return Utils::replaceImagesToBase64InHtml(apply_filters('the_content', $content));
    }
}
