<?php
namespace WCStepFilter\Product;

use WCStepFilter\L10N;
use WCStepFilter\TaxonomyTrait;
use WCStepFilter\TaxonomyInterface;
use WCStepFilter\Utils;

/**
 * Product Category Class
 *
 * @class Category
 * @version 1.0.0
 */
class Category implements TaxonomyInterface
{
    use TaxonomyTrait;

    /**
     * Taxonomy string
     * @var string
     */
    public static $taxonomy = 'product_cat';

    /**
     * Namespace string
     * @var string
     */
    public static $namespace = 'wcsf_product';

    /** Class Constructor */
    public function __construct()
    {
        $this->initTaxonomy();

        add_action('wp_ajax_woocommerce_json_search_category', [$this, 'jsonSearch']);
    }

    /** Register entity taxonomy */
    public function registerTaxonomy()
    {
        // already registered by WooCommerce
    }

    /**
     * Highlight categories menu item if it is active
     *
     * @param string $parentFile
     *
     * @return string
     */
    public function categoriesMenuItemHighlight($parentFile)
    {
        // override by default behavior
        return $parentFile;
    }

    /**
     * Get product category settings model array
     *
     * @return array
     */
    public static function getCategorySettingsModel()
    {
        return apply_filters(
            'wcsf_category_settings_model',
            [
                'pre_checked' => [
                    'label' => L10N::r('Step Filter Pre-checked'),
                    'key' => '_wcsf_pre_checked',
                    'type' => 'checkbox',
                    'default' => false
                ]
            ]
        );
    }

    /** Search for terms and echo json */
    public function jsonSearch()
    {
        ob_start();
        check_ajax_referer('search-products', 'security');

        $terms = get_terms([
            'taxonomy' => 'product_cat',
            'orderby' => 'id',
            'order' => 'ASC',
            'hide_empty' => false,
            'include' => !empty($_GET['include']) ? wp_parse_id_list($_GET['include']) : '',
            'exclude' => !empty($_GET['exclude']) ? wp_parse_id_list($_GET['exclude']) : '',
            'number' => !empty($_GET['limit']) ? intval($_GET['limit']) : '',
            'name__like' => $_GET['term']
        ]);

        $foundTerms = [];

        if (!empty($terms)) {
            foreach ($terms as $term) {
                $foundTerms[$term->term_id] = rawurldecode($term->name);
            }
        }

        Utils::sendJSON(apply_filters('woocommerce_json_search_found_categories', $foundTerms));
    }
}
