(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object'
        && typeof module !== 'undefined'
        && typeof require === 'function'
    ) {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    const $document = $(document);
    const $body = $(document.body);

    function toggleStyleSettingFields($element) {
        $element.closest('table')
            .find('tr:has([data-mode])').addClass('hidden')
            .filter(`:has([data-mode="${$element.val()}"])`)
            .removeClass('hidden');
    }

    function setQueryArg(args) {
        if (!window.history || !window.history.pushState) {
            return this;
        }

        const params = new URLSearchParams(window.location.search);

        for (let key in args) {
            if (args.hasOwnProperty(key)) {
                params.set(key, args[key]);
            }
        }

        const path = window.location.protocol + '//' + window.location.host + window.location.pathname
            + '?' + params.toString();

        window.history.pushState({path}, '', path);

        return this;
    }

    $document.ready(() => {
        $('[data-component~="wcsf-data-table-body-item"][data-key="source"] :input').each(function () {
            const $input = $(this);

            $input.closest('[data-component~="wcsf-data-table-body-item"]').attr('data-value', $input.val());
        });

        toggleStyleSettingFields($('#woocommerce_step_filter_custom_styles_mode'));
    });

    // custom styles mode change
    $document.on('change', '#woocommerce_step_filter_custom_styles_mode', function () {
        toggleStyleSettingFields($(this));
    });

    // re-launch some js fields
    $document.on('added.value.question.wcsf', (event, instance, $element) => {
        $body.trigger('wc-enhanced-select-init');
        $document.trigger('init.dataTable.wcsf');
        $document.trigger('init.thumbnail.wcsf');
        $document.trigger('init.ajaxSelect.wcsf');

        $element.find('[data-component~="wcsf-data-table-body-item"][data-key="source"] :input').each(function () {
            const $input = $(this);

            $input.closest('[data-component~="wcsf-data-table-body-item"]').attr('data-value', $input.val());
        });
    });

    // extra query setting source change
    $document.on('change', '[data-component~="wcsf-data-table-body-item"][data-key="source"] :input', function () {
        const $input = $(this);

        $input.closest('[data-component~="wcsf-data-table-body-item"]').attr('data-value', $input.val());
    });

    // data-table new item
    $document.on('added.item.dataTable.wcsf', () => {
        $body.trigger('wc-enhanced-select-init');
        $document.trigger('init.thumbnail.wcsf');
        $document.trigger('init.ajaxSelect.wcsf');
    });

    // open modal via JS too to be sure everything is alright (some 3rd code makes it wrong)
    $document.on('click', '[data-component~="wcsf-open-modal"]', function (event) {
        event.preventDefault();

        const href = $(this).attr('href');

        $(href).addClass('is-opened');

        if (history.pushState) {
            history.pushState(null, null, href);
        } else {
            location.hash = href;
        }
    });

    // close modal
    $document.on('click', '[data-component~="wcsf-modal-close"]', function () {
        $(this).closest('[data-component~="wcsf-modal"]').removeClass('is-opened');

        if (history.pushState) {
            history.pushState(null, null, '#');
        } else {
            location.hash = '#';
        }
    });

    // toggle settings group
    $document.on('click', '[data-component~="wcsf-settings-group-toggle"]', function (event) {
        event.preventDefault();

        const $element = $(this);
        const $groups = $element.closest('[data-component~="wcsf-settings-groups"]');
        const $content = $groups.find('[data-component~="wcsf-settings-group-content"]');
        const $toggle = $groups.find('[data-component~="wcsf-settings-group-toggle"]');
        const $selectedContent = $content.filter(`[data-id="${$element.data('id')}"]`);
        const isClosed = $selectedContent.attr('aria-expanded') === 'false';

        if (!isClosed) {
            $element.add($selectedContent).attr('aria-expanded', 'false');

            return this;
        }

        $toggle.add($content).attr('aria-expanded', 'false');
        $element.add($selectedContent).attr('aria-expanded', 'true');

        // save state to URL parameter
        setQueryArg({activeGroup: $element.data('id')});

        return this;
    });

    // inquiries pagination
    $document.on('click', '[data-component~="wcsf-inquiry-list-pagination"] a', function (event) {
        event.preventDefault();

        const $element = $(this);
        const $table = $element.closest('[data-component~="wcsf-inquiry-list-table"]');
        const params = new URLSearchParams(this.getAttribute('href'));
        const data = Object.fromEntries(params.entries());

        data.action = 'WCSFGetInquiriesListTable';
        data.total = $table.data('total');
        $table.addClass('is-loading');

        return $.get($table.data('ajax-url'), data, (response) => $table.replaceWith(response));
    });

    // purge inquiries
    $document.on('click', '[data-component~="wcsf-inquiries-purge"]', function (event) {
        if (!confirm(this.getAttribute('data-confirm-message'))) {
            event.preventDefault();
        }
    });
});
