<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Filter;
use \WCStepFilter\Template;

$arguments = Template::getHTMLArgs([
    'formId' => null,
    'stickyNav' => Filter::getSetting($id, 'sticky_nav'),
    'stickyNavOffsetTop' => Filter::getSetting($id, 'sticky_nav_offset_top'),
    'toggleMobileNavOn' => Filter::getSetting($id, 'toggle_mobile_nav_on', 'sm'),
    'navItems' => Filter::getNavItems($id)
]);

$isSticky = !in_array($arguments['stickyNav'], ['0', 'never']);
$class = [];

if ($isSticky) {
    $class[] = 'is-sticky' . (!in_array($arguments['stickyNav'], ['1', 'always']) ? "-{$arguments['stickyNav']}" : '');
}

if ($arguments['toggleMobileNavOn']) {
    $class[] = "d-none d-{$arguments['toggleMobileNavOn']}-block";
}
?>
<nav class="wcsf-nav is-tabs <?php echo esc_attr(implode(' ', $class))?>"
    data-component="wcsf-nav<?php echo $arguments['stickyNav'] ? ' wcsf-sticky-observer' : ''; ?>"<?php
    if ($isSticky && $arguments['stickyNavOffsetTop']) {
        if (is_int($arguments['stickyNavOffsetTop'])) {
            $arguments['stickyNavOffsetTop'] .= 'px';
        }

        echo ' style="top: ' . esc_attr($arguments['stickyNavOffsetTop']) . '"';
    }
    ?>>
    <ul class="wcsf-nav-list is-tabs nav nav-tabs" data-component="wcsf-nav-list" role="tablist">
        <?php foreach ($arguments['navItems'] as $navItem) { ?>
            <li role="presentation"
                class="wcsf-nav-list-item nav-item <?php echo esc_attr($navItem['class']); ?>">
                <button class="wcsf-nav-list-item-button nav-link <?php echo esc_attr($navItem['class']); ?>"
                    type="<?php echo esc_attr($navItem['type']); ?>" name="stepId"
                    value="<?php echo esc_attr($navItem['id']); ?>"
                    form="<?php echo esc_attr($arguments['formId']); ?>"
                    data-component="<?php echo esc_attr($navItem['component']); ?>"
                    data-id="<?php echo esc_attr($navItem['id']); ?>"<?php disabled($navItem['disabled']); ?>><?php
                    echo $navItem['thumbnail']
                        ? wp_get_attachment_image(
                            $navItem['thumbnail'],
                            'thumbnail',
                            false,
                            ['class' => 'wcsf-nav-list-item-button-thumbnail']
                        ) . ' '
                        : '';
                    ?><span class="wcsf-nav-list-item-button-inner"><?php
                        echo wp_kses_post($navItem['name']);
                        ?></span></button>
            </li>
        <?php } ?>
    </ul>
</nav>
