<?php
/**
 * Plugin Name: WooCommerce Step Filter
 * Description: Powerful and flexible plugin for creating step-by-step products filter
 * Version: 10.0.1
 * Author: پرشین اسکریپت
 * Author URI: https://www.persianscript.ir
 * Text Domain: woocommerce-step-filter
 * Domain Path: /languages/
 * Requires at least: 4.5
 * Requires PHP: 7.0
 * WC requires at least: 2.4
 * WC tested up to: 7.5.0
 */

namespace {

    defined('ABSPATH') || exit;

    $uploadDir = wp_upload_dir();

    if (!defined('WC_STEP_FILTER_VERSION')) {
        define('WC_STEP_FILTER_VERSION', '10.0.1');
    }

    if (!defined('WC_STEP_FILTER_PLUGIN_PATH')) {
        define('WC_STEP_FILTER_PLUGIN_PATH', plugin_dir_path(__FILE__));
    }

    if (!defined('WC_STEP_FILTER_PLUGIN_URL')) {
        define('WC_STEP_FILTER_PLUGIN_URL', plugin_dir_url(__FILE__));
    }

    if (!defined('WC_STEP_FILTER_PLUGIN_DIR_NAME')) {
        define('WC_STEP_FILTER_PLUGIN_DIR_NAME', plugin_basename(__DIR__));
    }

    if (!defined('WC_STEP_FILTER_PLUGIN_BASENAME')) {
        define('WC_STEP_FILTER_PLUGIN_BASENAME', plugin_basename(__FILE__));
    }

    if (!defined('WC_STEP_FILTER_THEME_TEMPLATES_DIR')) {
        define('WC_STEP_FILTER_THEME_TEMPLATES_DIR', 'woocommerce-step-filter');
    }

    if (!defined('WC_STEP_FILTER_DEBUG')) {
        if (defined('SCRIPT_DEBUG')) {
            define('WC_STEP_FILTER_DEBUG', SCRIPT_DEBUG);
        } else {
            define('WC_STEP_FILTER_DEBUG', false);
        }
    }

    if (!defined('WC_STEP_FILTER_UPLOADS_PATH')) {
        define(
            'WC_STEP_FILTER_UPLOADS_PATH',
            $uploadDir['basedir'] . DIRECTORY_SEPARATOR . 'woocommerce-step-filter' . DIRECTORY_SEPARATOR
        );
    }

    if (!defined('WC_STEP_FILTER_UPLOADS_URL')) {
        define(
            'WC_STEP_FILTER_UPLOADS_URL',
            $uploadDir['baseurl'] . DIRECTORY_SEPARATOR . 'woocommerce-step-filter' . DIRECTORY_SEPARATOR
        );
    }

    if (!class_exists('\WCStepFilter\Core')) {
        require_once(__DIR__ . '/includes/classes/Core.php');
    }

    require_once(__DIR__ . '/includes/global/shortcodes.php');
}

namespace WCStepFilter {

    if (!function_exists(__NAMESPACE__  . '\Instance')) {
        function Instance()
        {
            return Core::instance();
        }
    } else {
        add_filter('admin_notices', function () {
            ?>
            <div class="notice notice-warning is-dismissible">
                <p><strong><?php L10N::e('WooCommerce Step Filter is enabled a few times'); ?></strong></p>
                <p><?php
                    // phpcs:disable
                    L10N::e('A few WooCommerce Step Filter plugins are enabled at once. Keep enabled only one of them.');
                    // phpcs:enable
                    ?></p>
            </div>
            <?php
        });
    }

    $GLOBALS['WCStepFilter'] = Instance();

    // requests
    if (class_exists(__NAMESPACE__ . '\API')) {
        add_filter('plugins_api', [__NAMESPACE__ . '\API', 'pluginApiAction'], 20, 3);
        add_filter('site_transient_update_plugins', [__NAMESPACE__ . '\API', 'updatePluginAction']);
        add_action('upgrader_process_complete', [__NAMESPACE__ . '\API', 'pluginUpdatedAction'], 10, 2);
        register_activation_hook(__FILE__, function () {
            API::request(['action' => 'activate_plugin']);
        });

        register_deactivation_hook(__FILE__, function () {
            API::request(['action' => 'deactivate_plugin']);

            wp_clear_scheduled_hook('wcsf_cron');
        });
    }
}
